@@ -42,8 +42,7 @@ Mpris2::Mpris2(QObject* parent) : QObject(parent)
     if (!success)
         success = QDBusConnection::sessionBus().registerService(mpris2Name + ".instance" + QString::number(getpid()));
 
-    if (success)
-    {
+    if (success)  {
         new MediaPlayer2(this);
         new MediaPlayer2Player(this);
         QDBusConnection::sessionBus().registerObject("/org/mpris/MediaPlayer2", this, QDBusConnection::ExportAdaptors);
@@ -57,7 +56,7 @@ Mpris2::~Mpris2()
 void Mpris2::signalPropertiesChange(const QObject* adaptor, const QVariantMap& properties)
 {
     QDBusMessage msg = QDBusMessage::createSignal("/org/mpris/MediaPlayer2",
-        "org.freedesktop.DBus.Properties", "PropertiesChanged" );
+                                                  "org.freedesktop.DBus.Properties", "PropertiesChanged" );
 
     msg << adaptor->metaObject()->classInfo(0).value();
     msg << properties;
